import {
  Accordion,
  AccordionContent,
  AccordionItem,
  AccordionTrigger,
} from "@/components/ui/accordion";
import parse from "html-react-parser";
import styles from "./JobCardDescription.module.css";

interface JobPosting {
  title: string;
  logo: string;
  company: string;
  location: string;
  type: string;
  description: string;
  link: string;
  skills: {
    react: boolean;
    python: boolean;
    golang: boolean;
    svelte: boolean;
    nextjs: boolean;
    typescript: boolean;
    tailwind: boolean;
  };
}

export default async function JobCard(props: { job: JobPosting }) {
  const { title, logo, company, location, type, description, link, skills } =
    props.job;
  const parsedDescription = parse(description);

  return (
    <Accordion type="single" collapsible>
      <AccordionItem value="item-1">
        <AccordionTrigger>
          <div>
            <h2 className="text-2xl text-left">{title}</h2>
            <div className="text-left items-center space-x-4">
              <span className="">{company}</span>
              <span className="text-sm text-stone-500">{location}</span>
              <span className="text-sm text-stone-500">{type}</span>
            </div>
          </div>
          <div></div>
        </AccordionTrigger>
        <AccordionContent>
          <div className={`py-4 ${styles.parsedDescription}`}>
            {parsedDescription}
          </div>
        </AccordionContent>
      </AccordionItem>
    </Accordion>
  );
}
